==> mixxx_1.10.0~dfsg0.orig.tar.bz2: mixxx-1.10.0~dfsg0/src/defs_urls.h <==
/***************************************************************************
                          defs_urls.h  -  description
                             -------------------
    copyright            : (C) 2008 by Albert santoni
    email                :
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DEFS_URLS_H
#define DEFS_URLS_H

#define MIXXX_WEBSITE_URL       "http://www.mixxx.org"
#define MIXXX_SUPPORT_URL       "http://www.mixxx.org/support.php"
#define MIXXX_FEEDBACK_URL      "https://spreadsheets.google.com/a/mixxx.org/spreadsheet/viewform?formkey=dDlJeS12czk3SWtkVkNRd3UtNURUUkE6MQ"
#define MIXXX_TRANSLATION_URL   "https://translations.launchpad.net/mixxx/trunk/+pots/mixxx"
#define MIXXX_MANUAL_URL        "http://mixxx.org/manual/1.10"
#define MIXXX_MANUAL_FILENAME   "Mixxx-Manual.pdf"
#define MIXXX_PROMO_URL         "http://promo.mixxx.org/"

#endif

==> mixxx_1.10.1~dfsg0.orig.tar.bz2: mixxx-1.10.1~dfsg0.orig/src/defs_urls.h <==
/***************************************************************************
                          defs_urls.h  -  description
                             -------------------
    copyright            : (C) 2008 by Albert santoni
    email                :
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DEFS_URLS_H
#define DEFS_URLS_H

#define MIXXX_WEBSITE_URL       "http://www.mixxx.org"
#define MIXXX_SUPPORT_URL       "http://www.mixxx.org/support.php"
#define MIXXX_FEEDBACK_URL      "https://spreadsheets.google.com/a/mixxx.org/spreadsheet/viewform?formkey=dDlJeS12czk3SWtkVkNRd3UtNURUUkE6MQ"
#define MIXXX_TRANSLATION_URL   "https://translations.launchpad.net/mixxx"
#define MIXXX_MANUAL_URL        "http://mixxx.org/manual/1.10"
#define MIXXX_MANUAL_FILENAME   "Mixxx-Manual.pdf"
#define MIXXX_PROMO_URL         "http://promo.mixxx.org/"

#endif
